EntityType

Struct EntityType 

pub struct EntityType {
Show 15 fields pub key: Identifier, pub client_tracking_range: i32, pub update_interval: i32, pub track_deltas: bool, pub dimensions: EntityDimensions, pub fixed: bool, pub mob_category: MobCategory, pub fire_immune: bool, pub summonable: bool, pub can_spawn_far_from_player: bool, pub can_serialize: bool, pub is_abstract_boat: bool, pub is_abstract_minecart: bool, pub flags: EntityFlags, pub default_attributes: &'static [(&'static str, f64)],
}

Fields

key: Identifierclient_tracking_range: i32update_interval: i32track_deltas: bool

Whether vanilla ServerEntity tracks velocity deltas for this type.

dimensions: EntityDimensions

Default entity dimensions.

fixed: bool

If true, dimensions cannot be scaled.

mob_category: MobCategory

Mob category for spawn classification.

fire_immune: bool

Whether this entity is immune to fire damage.

summonable: bool

Whether this entity can be summoned via commands.

can_spawn_far_from_player: bool

Whether this entity can spawn far from players.

can_serialize: bool

Whether this entity type can be serialized to disk. Set to false for transient entities (lightning, fishing hooks, players).

is_abstract_boat: bool

Whether vanilla class hierarchy makes this entity an AbstractBoat.

is_abstract_minecart: bool

Whether vanilla class hierarchy makes this entity an AbstractMinecart.

flags: EntityFlags

Behavioral flags for collision and interaction.

default_attributes: &'static [(&'static str, f64)]

Default attribute base values for this entity type Empty for entities that don’t have attributes (projectiles, items, displays, etc.)